PyChatangoBot
=============

* License : MIT

Summary
-------

Asyncio implementation of Chatango Bot done by Lumirayz, see `Chatango Bot
Tutorial <https://sinister.ly/Thread-Tutorial-Chatango-Bot-Tutorial>`_.

You can run this as a single process program or multiprocesses.

There are runner scripts example not included when you pip install the package,
check them out at `PyChatangoBot <https://github.com/dozymoe/PyChatangoBot>`_,
we have "run-bot" for single process and "run-multibot" for multiple processes.


Installation
------------

Simply `pip install pychatangobot`.
